@@ -1,9 +1,15 @@
 from datetime import datetime
 from typing import Optional, Union, List
-
 from pydantic import BaseModel, Field, validator
 
 
+class Bot(BaseModel):
+    """
+    Contains your bot token
+    """
+    token: str
+
+
 class User(BaseModel):
     """
     https://core.telegram.org/bots/api#user
@@ -522,6 +528,58 @@ class InlineKeyboardButton(BaseModel):
     pay: Optional[bool]
 
 
+class ForceReply(BaseModel):
+    """
+    https://core.telegram.org/bots/api#forcereply
+    Upon receiving a message with this object,
+    Telegram clients will display a reply interface to the user
+    (act as if the user has selected the bot's message and tapped 'Reply')
+    """
+    force_reply: bool = True
+    input_field_placeholder: Optional[str]
+    selective: Optional[bool]
+
+
+class ReplyKeyboardRemove(BaseModel):
+    """
+    https://core.telegram.org/bots/api#replykeyboardremove
+    Upon receiving a message with this object, Telegram clients
+    will remove the current custom keyboard and display
+    the default letter-keyboard.
+    """
+    remove_keyboard: bool = True
+    selective: Optional[bool]
+
+
+class KeyboardButtonPollType(BaseModel):
+    """
+    https://core.telegram.org/bots/api#keyboardbuttonpolltype
+    This object represents type of a poll, which is allowed to be
+    created and sent when the corresponding button is pressed.
+    """
+    type: Optional[str] = None
+
+
+class WebAppInfo(BaseModel):
+    """
+    https://core.telegram.org/bots/api#webappinfo
+    Contains information about a Web App.
+    """
+    url: Optional[str] = None
+
+
+class KeyboardButton(BaseModel):
+    """
+    https://core.telegram.org/bots/api#keyboardbutton
+    This object represents one button of the reply keyboard.
+    """
+    text: str
+    request_contact: Optional[bool]
+    request_location: Optional[bool]
+    request_poll: Optional[KeyboardButtonPollType]
+    web_app: Optional[WebAppInfo]
+
+
 class InlineKeyboardMarkup(BaseModel):
     """
     https://core.telegram.org/bots/api#inlinekeyboardmarkup
@@ -531,6 +589,36 @@ class InlineKeyboardMarkup(BaseModel):
     inline_keyboard: Union[list, List[InlineKeyboardButton]]
 
 
+class ReplyKeyboardMarkup(BaseModel):
+    """
+    https://core.telegram.org/bots/api#replykeyboardmarkup
+    This object represents a custom keyboard with reply options
+    """
+    keyboard: Union[list, List[KeyboardButton]]
+    resize_keyboard: Optional[bool]
+    one_time_keyboard: Optional[bool]
+    input_field_placeholder: Optional[str]
+    selective: Optional[bool]
+
+
+class MessageToSend(BaseModel):
+    """
+    https://core.telegram.org/bots/api#sendmessage
+    Message data to use sendMessage method
+    """
+    chat_id: Union[str, int]
+    text: str
+    parse_mode: Optional[str] = None
+    entities: Union[list, MessageEntity, None] = None
+    disable_web_page_preview: Optional[bool] = None
+    disable_notification: Optional[bool] = None
+    protect_content: Optional[bool] = None
+    reply_to_message_id: Optional[int] = None
+    allow_sending_without_reply: Optional[bool] = None
+    reply_markup: Union[InlineKeyboardMarkup, ReplyKeyboardMarkup,
+                        ReplyKeyboardRemove, ForceReply, None] = None
+
+
 class Message(BaseModel):
     """
     https://core.telegram.org/bots/api#message
@@ -802,7 +890,7 @@ class ChatMemberUpdated(BaseModel):
         ChatMemberOwner, ChatMemberAdministrator,
         ChatMemberMember, ChatMemberRestricted,
         ChatMemberLeft, ChatMemberBanned]
-    invite_link: ChatInviteLink
+    invite_link: Optional[ChatInviteLink]
 
 
 class Update(BaseModel):
@@ -825,3 +913,18 @@ At most one of the optional parameters can be present in any given update.
     poll_answer: Optional[PollAnswer] = None
     my_chat_member: Optional[ChatMemberUpdated] = None
     chat_member: Optional[ChatMemberUpdated] = None
+
+
+class WebhookInfo(BaseModel):
+    """
+    Contains information about the current status of a webhook.
+    """
+
+    url: str
+    has_custom_certificate: bool
+    pending_update_count: int
+    ip_address: Optional[str] = None
+    last_error_date: Optional[datetime] = None
+    last_error_message: Optional[str] = None
+    max_connections: Optional[int] = None
+    allowed_updates: Union[list, str, None] = None
